@@ -101,6 +101,7 @@ static void Specify(char *what, SEXP value)
  */
     SEXP x;
     double v;
+    int iv;
     int success;
 
     success = 0;
@@ -135,6 +136,10 @@ static void Specify(char *what, SEXP value)
 	    }
    	}
     }
+    else if (streql(what, "skipRedraw")) {
+    	lengthCheck(what, value, 1);	iv = asLogical(value);
+    	rgl_setSkipRedraw(&success, &iv);
+    }
     else if (streql(what, "userMatrix")) {
 	dimCheck(what, value, 4, 4);
 	x = coerceVector(value, REALSXP);
@@ -193,6 +198,10 @@ static SEXP Query(char *what)
 	value = allocMatrix(REALSXP, 4, 4);
 	rgl_getProjMatrix(&success, REAL(value));    
     }
+    else if (streql(what, "skipRedraw")) {
+    	value = allocVector(LGLSXP, 1);
+    	rgl_getSkipRedraw(&success, LOGICAL(value));
+    }
     else if (streql(what, "userMatrix")) {
 	value = allocMatrix(REALSXP, 4, 4);
 	rgl_getUserMatrix(&success, REAL(value));
